import 'package:flutter/material.dart';
import 'package:flutter_ca_presentation/flutter_ca_presentation.dart';
import 'package:get_it/get_it.dart';
import 'package:get_it_mixin/get_it_mixin.dart';

abstract class StatefulView extends StatefulWidget {
  @override
  final Key? key;
  final RouteObserver? routeObserver;

  const StatefulView({this.routeObserver, this.key}) : super(key: key);
}

abstract class ViewState<View extends StatefulView, VM extends ViewModel>
    extends State<View> with WidgetsBindingObserver{
  late bool _isMounted;
  late VM viewModel;

  ViewState() {
    _isMounted = true;
    viewModel = GetIt.I.get<VM>()..addListener(_update);
  }

  void inActive() {}
  void detached() {}
  void paused() {}
  void resumed() {}

  void didUpdateViewModel() {}
  void _update() {
    didUpdateViewModel();
    setState(() => {});
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    if (_isMounted) {
      switch (state) {
        case AppLifecycleState.inactive:
          inActive();
          break;
        case AppLifecycleState.paused:
          paused();
          break;
        case AppLifecycleState.resumed:
          resumed();
          break;
        case AppLifecycleState.detached:
          detached();
          break;
      }
    }
  }

  @override
  void dispose() {
    viewModel.removeListener(_update);
    super.dispose();
  }
}
