import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:get_it/get_it.dart';

import 'stateful_view.dart';
import 'view_model.dart';

void main() {
  TestWidgetsFlutterBinding.ensureInitialized();

  late Widget statefulWidget;

  group('Presentation test suit', () {
    setUpAll(() async {
      GetIt.I.registerLazySingleton<CounterViewModel>(() => CounterViewModel());

      await GetIt.I.allReady();

      statefulWidget = const MaterialApp(
        home: StatefulCounterView(),
      );
    });

    testWidgets('Should render and execute changes on stateful view',
            (WidgetTester tester) async {
          await tester.pumpWidget(statefulWidget);

          final increaseButton = find.text('Increase');
          final decreaseButton = find.text('Decrease');

          expect(increaseButton, findsOneWidget);
          expect(decreaseButton, findsOneWidget);

          await tester.tap(increaseButton);
          await tester.pumpAndSettle();
          expect(find.text('1'), findsOneWidget);

          await tester.tap(decreaseButton);
          await tester.pumpAndSettle();
          expect(find.text('0'), findsOneWidget);
        });
  });
}
